% 1 Nov 2017 Porto 
% Alper Cenesiz & Luis Guimaraes
% Model with real wage rigidities
% y - aggregate output 
% p - aggregate price 
% yc - nondurable output 
% pc - nondurable price
% pcs - optimal nondurable price
% yx - durable output 
% px - durable price
% pxs - optimal durable price
% d - stock of durable good
% kc(kx) - capital stock in nondurable(durable) sector
% nc(nx) - labor in nondurable(durable) sector
% n - aggregate labor
% l - lagrange multiplier associated with household's nominal budget constraint
% mc - marginal cost
% wr - real wage
% w - nominal wage
% m - money

% beta, delta, alpha, and gamma are defined in the paper
% thetax calvo parameter in durable sector
% thetac calvo parameter in nondurable sector
% psic is the weight of nondurables in GDP

close all;

%----------------------------------------------------------------
% 1. Defining variables
%----------------------------------------------------------------
var y yx yc d kx kc w mc px pc n nx nc l pxs pcs p m wr;
    
varexo e;

parameters 
beta delta thetax thetac psic alpha gamma;

%----------------------------------------------------------------
% 2. Calibration
%----------------------------------------------------------------
beta = 0.9951;
thetac = 0.6534;
thetax = 0;
delta = 0.0123;
psic = .75; 
alpha = .35;
gamma = 1; // full real wage rigidity

%----------------------------------------------------------------
% 3. Model 
%----------------------------------------------------------------
model(linear); 

0=yc+l+pc; //foc wrt nondurable consumption
0=(1-beta*(1-delta))*d+l+px-beta*(1-delta)*(l(+1)+px(+1)); //foc wrt durable consumption
d=delta*yx+(1-delta)*d(-1); //law of motion for durables
wr=gamma*wr(-1)+(1-gamma)*(n+yc+pc-p); // law of motion of real wages
wr=w-p; // definition of real wages
n=(1-psic)*nx+psic*nc; //aggregate labor
y=psic*yc+(1-psic)*yx; //aggregate output
0=psic/(1-psic)*kc+kx; //aggregate capital which is fixed
yx=alpha*kx+(1-alpha)*nx; // durable production function
yc=alpha*kc+(1-alpha)*nc; // nondurable production function
w=yx-nx+mc; // labor demand in durable sector
w=yc-nc+mc; // labor demand in nondurable sector
p+y=(1-psic)*(px+yx)+psic*(pc+yc); // nominal GDP
m=p+y; // money demand
m=m(-1)+e; // money supply
pxs=thetax*beta*pxs(+1)+(1-thetax*beta)*mc; //calvo equation durables
pcs=thetac*beta*pcs(+1)+(1-thetac*beta)*mc; //calvo equation nondurables
px=thetax*px(-1)+(1-thetax)*pxs; // price index durables
pc=thetac*pc(-1)+(1-thetac)*pcs; // price index nondurables

end;
%----------------------------------------------------------------
shocks;
var e  = 1;
end;
check;
steady;

stoch_simul(irf=15, hp_filter=0)  y wr yc yx pc px;//